@@ -19,10 +19,10 @@
 #include <bonobo/bonobo-ui-toolbar-control-item.h>
 
 /* To debug plug/socket/control render issues */
-#undef DEBUG_CONTROL
+#define noDEBUG_CONTROL
 
 /* To dump lots of sequence information */
-#undef DEBUG_UI
+#define noDEBUG_UI
 
 int        bonobo_ui_preferences_shutdown (void);
 void       bonobo_ui_image_set_pixbuf     (GtkImage       *image,
